<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 03/22/2004 *
 * ===================                          Last change: 06/28/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : ext-sponsor.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : Sponsor area                                     *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Sponsorenbereich                                 *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Version number
setThisExtensionVersion('0.0.0');

// Version history array (add more with , '0.0.1' and so on)
setExtensionVersionHistory(array('0.0.0'));

// This extension is in development (non-productive)
enableExtensionProductive(false);

switch (getExtensionMode()) {
	case 'register': // Do stuff when installation is running
		// Try to make it depend on repair
		addExtensionDependency('repair');

		//
		// Sponsor data
		//
		addDropTableSql('sponsor_data');
		addCreateTableSql('sponsor_data', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`company` VARCHAR(255) NOT NULL DEFAULT '',
`position` VARCHAR(255) NOT NULL DEFAULT '',
`tax_ident` VARCHAR(255) NOT NULL DEFAULT '',
`gender` ENUM('M','F','C') NOT NULL DEFAULT 'M',
`surname` VARCHAR(255) NOT NULL DEFAULT '',
`family` VARCHAR(255) NOT NULL DEFAULT '',
`street_nr1` VARCHAR(255) NOT NULL DEFAULT '',
`street_nr2` VARCHAR(255) NOT NULL DEFAULT '',
`zip` VARCHAR(6) NOT NULL DEFAULT '',
`city` VARCHAR(255) NOT NULL DEFAULT '',
`country` CHAR(2) NOT NULL DEFAULT 'DE',
`phone` VARCHAR(255) NOT NULL DEFAULT '',
`fax` VARCHAR(255) NOT NULL DEFAULT '',
`cell` VARCHAR(255) NOT NULL DEFAULT '',
`email` VARCHAR(255) NOT NULL DEFAULT '',
`url` VARCHAR(255) NOT NULL DEFAULT '',
`password` VARCHAR(255) NOT NULL DEFAULT '',
`remote_addr` VARCHAR(15) NOT NULL DEFAULT '0.0.0.0',
`sponsor_created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
`last_online` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`last_change` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`status` ENUM('UNCONFIRMED','PENDING','CONFIRMED','LOCKED') NOT NULL DEFAULT 'UNCONFIRMED',
`receive_warnings` ENUM('Y','N') NOT NULL DEFAULT 'Y',
`warning_interval` BIGINT(20) UNSIGNED NOT NULL DEFAULT '".(getOneDay()*7)."',
`points_amount` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`points_used` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`refid` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`ref_count` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`hash` VARCHAR(32) NULL DEFAULT NULL,
`last_payment` FLOAT(7,2) UNSIGNED NOT NULL DEFAULT 0.00,
`last_currency` VARCHAR(255) NOT NULL DEFAULT '&euro;',
PRIMARY KEY (`id`),
UNIQUE (`hash`),
INDEX (`refid`),
INDEX (`email`)",
			'Main sponsor data');
		//
		// Sponsor orders
		//
		addDropTableSql('sponsor_orders');
		addCreateTableSql('sponsor_orders', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`sponsor_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`admin_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`regid` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`payment_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`pay_count` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`pay_status` ENUM('PENDING','PAYED','UNPAYED','DELETED') NOT NULL DEFAULT 'PENDING',
`pay_ordered` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
`pay_done` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
PRIMARY KEY (`id`),
INDEX (`payment_id`),
INDEX (`regid`),
INDEX (`admin_id`),
INDEX (`sponsor_id`)",
			'Sponsor orders table');
		//
		// Pay-types
		//
		addDropTableSql('sponsor_paytypes');
		addCreateTableSql('sponsor_paytypes', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`pay_name` VARCHAR(255) NOT NULL DEFAULT '',
`pay_rate` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`pay_min_count` BIGINT(20) UNSIGNED NOT NULL DEFAULT 1,
`pay_currency` VARCHAR(255) NOT NULL DEFAULT '&euro;',
PRIMARY KEY (`id`)",
			'Sponsor payment types');
		//
		// Points-to-action converting
		//
		addDropTableSql('sponsor_action_convert');
		addCreateTableSql('sponsor_action_convert', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`ext_name` VARCHAR(255) NOT NULL DEFAULT 'sponsor',
`conv_rate` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`conv_name` VARCHAR(255) NOT NULL DEFAULT 'Mails',
PRIMARY KEY (`id`),
INDEX (`ext_name`)",
			'Points to action convertion data');
		//
		// Sponsor menu system (default)
		//
		addDropTableSql('sponsor_menu');
		addCreateTableSql('sponsor_menu', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`action` VARCHAR(255) NOT NULL DEFAULT '',
`what`  VARCHAR(255) NULL DEFAULT NULL,
`title` VARCHAR(255) NOT NULL DEFAULT '',
`active` ENUM('Y','N') NOT NULL DEFAULT 'N',
`sort` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
PRIMARY KEY (`id`),
UNIQUE INDEX `action_what` (`action`,`what`),
UNIQUE (`what`),
INDEX (`action`)",
			'Sponsor menu');
		//
		// Registry for performable actions by your sponsors
		//
		addDropTableSql('sponsor_registry');
		addCreateTableSql('sponsor_registry', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`admin_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`ext_name` VARCHAR(255) NOT NULL DEFAULT 'sponsor',
`is_active` ENUM('Y','N') NOT NULL DEFAULT 'N',
`stamp_added` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
PRIMARY KEY (`id`),
INDEX (`ext_name`),
INDEX (`admin_id`)",
			'Sponsor action registry');
		//
		// URLs from the sponsors
		//
		addDropTableSql('sponsor_urls');
		addCreateTableSql('sponsor_urls', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`sponsor_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`url` VARCHAR(255) NOT NULL DEFAULT 'http://',
`title` VARCHAR(255) NOT NULL DEFAULT '',
`clicks` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`status` ENUM('PENDING','ACTIVE','LOCKED') NOT NULL DEFAULT 'PENDING',
PRIMARY KEY (`id`),
INDEX (`sponsor_id`)",
			'URLs from all sponsors');
		//
		// Banners of any size from the sponsors
		//
		addDropTableSql('sponsor_banner');
		addCreateTableSql('sponsor_banner', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`sponsor_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`url` VARCHAR(255) NOT NULL DEFAULT 'http://',
`alternate` VARCHAR(255) NOT NULL DEFAULT '',
`width` INT(7) UNSIGNED NOT NULL DEFAULT 468,
`height` INT(7) UNSIGNED NOT NULL DEFAULT 60,
`views` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`status` ENUM('PENDING','ACTIVE','LOCKED') NOT NULL DEFAULT 'PENDING',
PRIMARY KEY (`id`),
INDEX (`sponsor_id`)",
			'Banners from all sponsors');
		//
		// Campaigns
		//
		addDropTableSql('sponsor_campaigns');
		addCreateTableSql('sponsor_campaigns', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`sponsor_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`admin_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`campaign_name` VARCHAR(255) NOT NULL DEFAULT '',
`campaign_created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
`campaign_start` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`campaign_end` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`campaign_amount` FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 0.00000,
`campaign_expired` ENUM('Y','N') NOT NULL DEFAULT 'N',
`campaign_locked` ENUM('Y','N') NOT NULL DEFAULT 'Y',
`campaign_ended` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`locked_reason` TINYTEXT,
`locked_timestamp` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`status` ENUM('PENDING','ACTIVE','LOCKED') NOT NULL DEFAULT 'PENDING',
PRIMARY KEY (`id`),
INDEX (`admin_id`),
INDEX (`sponsor_id`)",
			'Sponsor campaigns');
		//
		// Campaigns + URLs + Banner
		//
		addDropTableSql('sponsor_campaign_assigns');
		addCreateTableSql('sponsor_campaign_assigns', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`campaignid` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`urlid` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`bannerid` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`clicks` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`views` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
PRIMARY KEY (`id`),
INDEX (`bannerid`),
INDEX (`urlid`),
INDEX (`campaignid`)",
			'Campaign+Banner+URL connection data');
		//
		// Allowed data to display (administrative)
		//
		addDropTableSql('sponsor_admin_data');
		addCreateTableSql('sponsor_admin_data', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`data_row` VARCHAR(255) NOT NULL DEFAULT '',
`display` ENUM('Y','N') NOT NULL DEFAULT 'N',
PRIMARY KEY (`id`)",
			'Allowed data to display to the admin');
		//
		// Allowed data to display (sponsor-side)
		//
		addDropTableSql('sponsor_display_data');
		addCreateTableSql('sponsor_display_data', "
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`sponsor_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`data_row` VARCHAR(255) NOT NULL DEFAULT '',
`display` ENUM('Y','N') NOT NULL DEFAULT 'N',
PRIMARY KEY (`id`),
INDEX (`sponsor_id`)",
			'Data sponsors allowed to see');
		//
		// Default allowed data to display
		//
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('id','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('company','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('position','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('tax_ident','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('gender','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('surname','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('family','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('street_nr1','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('street_nr2','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('zip','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('city','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('country','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('phone','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('fax','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('email','Y')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('url','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('password','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('remote_addr','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('sponsor_created','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('last_online','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('last_change','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('status','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('receive_warnings','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('warning_interval','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('points_amount','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('points_used','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('refid','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('ref_count','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('hash','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('last_payment','N')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_admin_data` (`data_row`,`display`) VALUES ('last_currency','N')");
		//
		// Add default entries
		//
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_registry` (`ext_name`,`is_active`,`admin_id`,`stamp_added`) VALUES ('sponsor','N',".getCurrentAdminId().",NOW())");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_action_convert` (`ext_name`,`conv_rate`,`conv_name`) VALUES ('sponsor',10,'Mails')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_paytypes` (`pay_name`,`pay_min_count`,`pay_rate`,`pay_currency`) VALUES ('Standard-Paket', 5, 1000.00000, '&euro;')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_paytypes` (`pay_name`,`pay_min_count`,`pay_rate`,`pay_currency`) VALUES ('Spar-Paket', 1, 200.00000, '&euro;')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_paytypes` (`pay_name`,`pay_min_count`,`pay_rate`,`pay_currency`) VALUES ('Power-Paket', 10, 2000.00000, '&euro;')");
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_sponsor_paytypes` (`pay_name`,`pay_min_count`,`pay_rate`,`pay_currency`) VALUES ('Sponsor-Paket', 20, 4000.00000, '&euro;')");
		//
		// Admin menu
		//
		addAdminMenuSql('sponsor', NULL, 'Sponsorenbereich','Den Sponsorenbereich verwalten. Hier k&ouml;nnen Sie auch Sonderaktionen seperat deakvieren oder wieder aktivieren, Sponsorenaccounts verwalten usw.', 7);
		addAdminMenuSql('sponsor','add_sponsor','Neuer Sponsor','Neues Sponsorenaccount hinzuf&uuml;gen.', 1);
		addAdminMenuSql('sponsor','unlock_sponsor','Sponsor freischalten','Sponsorenaccounts freigeben / sperren.', 2);
		addAdminMenuSql('sponsor','list_sponsor','Sponsoren auflisten','Listet alle verf&uuml;gbaren Sponsorenaccounts auf.', 3);
		addAdminMenuSql('sponsor','edit_sponsor','Sponsor &auml;ndern','Sponsorenaccount &auml;ndern (Grundaten, nicht Freigabe!).', 4);
		addAdminMenuSql('sponsor','lock_sponsor','Sponsor ent-/sperren','Sponsorenaccount sperren und entsperren.', 5);
		addAdminMenuSql('sponsor','del_sponsor','Sponsor l&ouml;schen','Sponsorenaccount l&ouml;schen.', 6);
		addAdminMenuSql('sponsor','sponsor_contct','Sponsor kontaktieren','Kontaktieren Sie Sponsoren komfortabel &uuml;ber dieses {?TITLE?}.', 7);
		addAdminMenuSql('sponsor','allow_sponsor_data','Datenverwaltung','Stellen Sie hier ein, welche Daten der Sponsor im Mitgliedsbereich &uuml;ber sicht anzeigen darf und welche nicht.', 8);
		addAdminMenuSql('sponsor','list_sponsor_pays','Bestellungen...','Bestellungen der Sponsoren auflisten / bearbeiten.', 9);
		addAdminMenuSql('sponsor','list_sponsor_campaigns','Kampagnen...','Management aller von Ihren Sponsoren eingerichteten Kampagnen.', 10);
		addAdminMenuSql('sponsor','list_sponsor_urls','URL-Management','Management (freischalten, sperren, l&ouml;schen, testen, bearbeiten usw.) von gebuchten URLs.', 11);
		addAdminMenuSql('sponsor','list_sponsor_banner','Banner-Management','Management (freischalten, sperren, l&ouml;schen, testen, bearbeiten usw.) von gebuchten Bannern.', 12);
		addAdminMenuSql('sponsor','list_sponsor_reg','Sponsor-Aktionen','Alle Sponsor-Aktionen auflisten und verwalten.', 13);
		addAdminMenuSql('sponsor','list_sponsor_pay','Buchungspakete','Die Sponsoren k&ouml;nnen sich {OPEN_CONFIG}POINTS{CLOSE_CONFIG}-Pakete kaufen. Hier k&ouml;nnen Sie diese verwalten.', 14);
		addAdminMenuSql('sponsor','list_sponsor_conv','{OPEN_CONFIG}POINTS{CLOSE_CONFIG} umwandeln...','Mit den vom Sponsor gekauften {OPEN_CONFIG}POINTS{CLOSE_CONFIG} kann er Aktionen buchen. Hier stellen Sie die Umrechnungsrate von {OPEN_CONFIG}POINTS{CLOSE_CONFIG} nach Sponsoraktionen um. Beispiel: 1 {OPEN_CONFIG}POINTS{CLOSE_CONFIG} = 10 Mails.', 15);
		addAdminMenuSql('sponsor','config_sponsor','Einstellungen','Allgemeine Einstellungen am Sponsoring-System.', 16);
		addAdminMenuSql('repair','repr_sponsor','Sponsormen&uuml;','Gewichtung des Sponsormen&uuml;s reparieren.', 5);
		//
		// Menu system (still admin menu)
		//
		addAdminMenuSql('menu','sponsor_medit','Sponsor-Men&uuml; editieren','Hier k&ouml;nnen Sie das Sponsorenmen&uuml; ver&auml;ndern: Positionen ver&auml;ndern, Men&uuml;titel &auml;ndern usw.', 7);
		addAdminMenuSql('menu','sponsor_madd','Sponsor-Men&uuml; hinzuf&uuml;gen','Hier k&ouml;nnen Sie einen neuen Men&uuml;punkt hinzuf&uuml;gen (falls Sie z.B. eigene Sponsoraktionen entwickelt haben oder welche versehendlich gel&ouml;scht haben.', 8);
		//
		// Guest menu
		//
		addGuestMenuSql('sponsor', NULL, 'Sponsoren', 2);
		addGuestMenuSql('sponsor', 'sponsor_reg', 'Anmeldung', 1);
		addGuestMenuSql('sponsor', 'sponsor_login', 'Einloggen', 2);
		addGuestMenuSql('sponsor', 'sponsor_infos', 'Infos/Preise', 3);
		addGuestMenuSql('sponsor', 'sponsor_agb', 'AGBs', 4);
		//
		// Member menu
		//
		addMemberMenuSql('main', 'sponsor_list', 'Unsere Sponsoren', 8);
		addMemberMenuSql('main', 'sponsor_reg', 'Sponsor werden', 9);
		//
		// Add default menus to sponsor menu
		//
		addSponsorMenuSql('main', NULL, 'Hauptauswahl', 'N', 1);
		addSponsorMenuSql('main', 'welcome', 'Willkommen', 'N', 1);
		addSponsorMenuSql('main', 'account', 'Ihr Account', 'N', 2);
		addSponsorMenuSql('main', 'campaigns', 'Kampagnen', 'N', 3);
		addSponsorMenuSql('main', 'list_urls', 'URL-Management', 'N', 4);
		addSponsorMenuSql('main', 'list_banner', 'Banner-Management', 'N', 5);
		addSponsorMenuSql('main', 'settings', 'Einstellungen', 'N', 6);
		addSponsorMenuSql('main', 'fillup', 'Konto auff&uuml;llen', 'N', 7);
		addSponsorMenuSql('main', 'stats', 'Statistiken', 'N', 8);
		addSponsorMenuSql('main', 'inquiry', 'Kontaktanfrage', 'N', 9);
		addSponsorMenuSql('main', 'refid', 'Referral-Link', 'N', 10);
		addSponsorMenuSql('actions', NULL, 'Sponsorenaktionen', 'N', 2);
		addSponsorMenuSql('actions', 'mail', 'Sponsor-Mail', 'N', 1);
		addSponsorMenuSql('actions', 'banner', 'Banner buchen', 'N', 2);
		addSponsorMenuSql('actions', 'text', 'Textlink buchen', 'N', 3);
		addSponsorMenuSql('logout', NULL, 'Ausloggen', 'N', 3);
		addSponsorMenuSql('logout', 'logout', 'Ausloggen', 'N', 1);
		addSponsorMenuSql('logout', 'guest', 'Zum Gastbereich', 'N', 2);
		//
		// General configuration stuff
		//
		addConfigAddSql('sponsor_ref_points', 'FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 100.00000');
		addConfigAddSql('sponsor_min_points', 'FLOAT(20,5) UNSIGNED NOT NULL DEFAULT 1000.00000');
		//
		// Register module
		//
		addModuleSql('sponsor', '{OPEN_TEMPLATE}MODULE_SPONSOR_TITLE{CLOSE_TEMPLATE}', 'Y', 'Y', 'N', 'N');
		addModuleSql('sponsor_confirm', '{OPEN_TEMPLATE}MODULE_SPONSOR_CONFIRM_TITLE{CLOSE_TEMPLATE}', 'Y', 'Y', 'N', 'N');
		addModuleSql('sponsor_ref', '{OPEN_TEMPLATE}MODULE_SPONSOR_REF_TITLE{CLOSE_TEMPLATE}', 'Y', 'Y', 'N', 'N');
		break;

	case 'remove': // Do stuff when removing extension
		// SQL commands to run
		addDropTableSql('sponsor_data');
		addDropTableSql('sponsor_orders');
		addDropTableSql('sponsor_action_convert');
		addDropTableSql('sponsor_paytypes');
		addDropTableSql('sponsor_menu');
		addDropTableSql('sponsor_registry');
		addDropTableSql('sponsor_urls');
		addDropTableSql('sponsor_banner');
		addDropTableSql('sponsor_campaigns');
		addDropTableSql('sponsor_campaign_assigns');
		addDropTableSql('sponsor_admin_data');
		addDropTableSql('sponsor_display_data');
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_admin_menu` WHERE `action`='sponsor' OR `what` IN('repr_sponsor','sponsor_medit','sponsor_madd')");
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_guest_menu` WHERE `action`='sponsor'");
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_member_menu` WHERE `what` IN('sponsor_list','sponsor_reg')");
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_mod_reg` WHERE `module` IN ('sponsor','sponsor_confirm','sponsor_ref') LIMIT 3");
		break;

	case 'activate': // Do stuff when admin activates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_guest_menu` SET `visible`='Y',`locked`='N' WHERE `action`='sponsor'");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_member_menu` SET `visible`='Y',`locked`='N' WHERE `what`='sponsor' LIMIT 1");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_sponsor_menu` SET `active`='Y' WHERE active='N'");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_sponsor_registry` SET `is_active`='Y' WHERE `is_active`='N'");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_mod_reg` SET `locked`='N',`hidden`='N',`admin_only`='N',`mem_only`='N' WHERE `module` IN ('sponsor','sponsor_confirm','sponsor_ref') LIMIT 3");
		break;

	case 'deactivate': // Do stuff when admin deactivates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_guest_menu` SET `visible`='N',`locked`='Y' WHERE `action`='sponsor'");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_member_menu` SET `visible`='N',`locked`='Y' WHERE `what`='sponsor' LIMIT 1");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_sponsor_menu` SET `active`='N' WHERE `active`='Y'");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_sponsor_registry` SET `is_active`='N' WHERE `is_active`='Y'");
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_mod_reg` SET `locked`='Y' WHERE `module` IN ('sponsor','sponsor_confirm','sponsor_ref') LIMIT 3");
		break;

	case 'update': // Update an extension
		switch (getCurrentExtensionVersion()) {
			case '0.0.1': // SQL queries for v0.0.1
				addExtensionSql('');

				// Update notes (these will be set as task text!)
				setExtensionUpdateNotes('');
				break;
		} // END - switch
		break;

	case 'modify': // When the extension got modified
		break;

	case 'test': // For testing purposes
		break;

	case 'init': // Do stuff when extension is initialized
		break;

	default: // Unknown extension mode
		logDebugMessage(__FILE__, __LINE__, sprintf("Unknown extension mode %s in extension %s detected.", getExtensionMode(), getCurrentExtensionName()));
		break;
} // END - switch

// [EOF]
?>
