<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/29/2003 *
 * ===================                          Last change: 11/11/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : install-inc.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : Functions for installation procedure             *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Funktionen fuer die Installationsroutine         *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isInstallationPhase())) {
	die();
} // END - if

// Load extension timezone
loadExtension('timezone', 'test');

// Set config entry
setConfigEntry('timezone', 'Europe/Berlin');

// And init timezone
FILTER_INIT_TIMEZONE(array());

// Init variables
$GLOBALS['install_mysql'] = array();
if ((isPostRequestElementSet('mysql')) && (ifPostContainsSelections('mysql'))) {
	// Transfer 'mysql' array
	$GLOBALS['install_mysql'] = postRequestElement('mysql');
} // END - if

// Check if both passwords from SMTP are matching
if ((isGetRequestElementSet('install_page') && (getRequestElement('install_page') == 5))) {
	// Okay, we have to check it
	if (isPostRequestElementSet('smtp_user') && (!isPostRequestElementSet('smtp_host'))) {
		// Hostname not set
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_HOSTNAME_EMPTY--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if

	if ((!isPostRequestElementSet('smtp_pass1')) && (isPostRequestElementSet('smtp_pass2'))) {
		// Password is empty
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_PASSWORD1_EMPTY--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if

	if ((isPostRequestElementSet('smtp_pass1')) && (!isPostRequestElementSet('smtp_pass2'))) {
		// Password repeat is empty
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_PASSWORD2_EMPTY--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if

	if (postRequestElement('smtp_pass1') != postRequestElement('smtp_pass1')) {
		// Passwords are not matching
		addToInstallContent('<div class="para">{--INSTALLER_SMTP_PASS_MISMATCH--}</div>');
		setGetRequestElement('install_page', 3);
	} // END - if
} // END - if

// Is the mailer installed or no admin registered so far?
if ((!isInstalled()) || (!isAdminRegistered())) {
	// Output page for entered value
	switch (getRequestElement('install_page')) {
		case 'welcome': // Welcome to the installation!
			addTemplateToInstallContent('install_welcome');
			break;

		case '1': // Server path, base URL
			// Load template
			addTemplateToInstallContent('install_page1');
			break;

		case '2': // Database login data
			if (empty($GLOBALS['install_mysql']['dbase']))  $GLOBALS['install_mysql']['dbase']  = 'your_database';
			if (empty($GLOBALS['install_mysql']['login']))  $GLOBALS['install_mysql']['login']  = 'your_login';
			if (empty($GLOBALS['install_mysql']['host']))   $GLOBALS['install_mysql']['host']   = 'localhost';
			if (empty($GLOBALS['install_mysql']['prefix'])) $GLOBALS['install_mysql']['prefix'] = 'mailer';
			if (empty($GLOBALS['install_mysql']['type']))   $GLOBALS['install_mysql']['type']   = 'MyISAM';
			if (ifFatalErrorsDetected()) {
				addToInstallContent('<div class="install_fatal"><ul>');
				foreach (getFatalArray() as $key => $err) {
					addToInstallContent('<li> {--FATAL_NO--}' . ($key + 1) . ': ' . $err . '</li>');
				} // END - foreach
				addToInstallContent('</ol></div>');
			} // END - if

			$content['mysql_host']   = $GLOBALS['install_mysql']['host'];
			$content['mysql_dbase']  = $GLOBALS['install_mysql']['dbase'];
			$content['mysql_prefix'] = $GLOBALS['install_mysql']['prefix'];
			$content['mysql_login']  = $GLOBALS['install_mysql']['login'];
			$content['table_type']   = $GLOBALS['install_mysql']['type'];
			$content['spath']        = postRequestElement('spath');
			$content['burl']         = postRequestElement('burl');
			$content['title']        = postRequestElement('title');
			$content['slogan']       = postRequestElement('slogan');
			$content['email']        = postRequestElement('email');

			// Load template
			addTemplateToInstallContent('install_page2', $content);
			break;

		case '3':
			// Set more values
			$content['spath']      = postRequestElement('spath');
			$content['burl']       = postRequestElement('burl');
			$content['title']      = postRequestElement('title');
			$content['slogan']     = postRequestElement('slogan');
			$content['email']      = postRequestElement('email');

			// Use default SMTP data
			$smtpHost  = '{?SMTP_HOSTNAME?}';
			$smtpUser  = '{?SMTP_USER?}';
			$smtpPass1 = '{?SMTP_PASSWORD?}';
			$smtpPass2 = '{?SMTP_PASSWORD?}';

			// Overwrite it with the data from sent (failed) form
			if (isPostRequestElementSet('smtp_host')) $smtpHost = postRequestElement('smtp_host');
			if (isPostRequestElementSet('smtp_user')) $smtpUser = postRequestElement('smtp_user');
			if (isPostRequestElementSet('smtp_pass')) {
				$smtpPass1 = postRequestElement('smtp_pass');
				$smtpPass2 = postRequestElement('smtp_pass');
			} // END - if

			// Database login data
			$content['mysql_host']   = $GLOBALS['install_mysql']['host'];
			$content['mysql_dbase']  = $GLOBALS['install_mysql']['dbase'];
			$content['mysql_prefix'] = $GLOBALS['install_mysql']['prefix'];
			$content['table_type']   = $GLOBALS['install_mysql']['type'];
			$content['mysql_login']  = $GLOBALS['install_mysql']['login'];
			$content['mysql_pass1']  = $GLOBALS['install_mysql']['pass1'];
			$content['mysql_pass2']  = $GLOBALS['install_mysql']['pass2'];

			// Set constants for SMTP data
			$content['smtp_host']  = $smtpHost;
			$content['smtp_user']  = $smtpUser;
			$content['smtp_pass1'] = $smtpPass1;
			$content['smtp_pass2'] = $smtpPass2;

			// Load template
			addTemplateToInstallContent('install_page3', $content);
			break;

		case '5': // Misc settings
			// General settings
			$content['spath']  = postRequestElement('spath');
			$content['burl']   = postRequestElement('burl');
			$content['title']  = postRequestElement('title');
			$content['slogan'] = postRequestElement('slogan');
			$content['email']  = postRequestElement('email');

			// SMTP settings
			$content['smtp_host'] = postRequestElement('smtp_host');
			$content['smtp_user'] = postRequestElement('smtp_user');
			$content['smtp_pass'] = postRequestElement('smtp_pass1');

			// Database login data
			$OUT = '';
			foreach ($GLOBALS['install_mysql'] as $key => $value) {
				$OUT .= '    <input type="hidden" name="mysql[' . $key . ']" value="' . $value . '" />';
			} // END - foreach
			$content['mysql_hidden'] = $OUT;

			// Load template
			addTemplateToInstallContent('install_page5', $content);
			break;

		case 'finalize': // Write captured data to files
			if ((isPostRequestElementSet('finalize')) && (!isInstalled())) {
				// You have submitted data then we have to reset the SQLs
				initSqls();

				/*
				 * Restore PHPs error handler to prevent ours to handle errors,
				 * e.g. failed connection attempts. We want to handle them on
				 * our own.
				 */
				restore_error_handler();

				// Connect to database server
				SQL_CONNECT($GLOBALS['install_mysql']['host'], $GLOBALS['install_mysql']['login'], $GLOBALS['install_mysql']['pass1'], __FILE__, __LINE__);

				// Is the link up?
				if (SQL_IS_LINK_UP()) {
					// Seems to work, also right database?
					if (SQL_SELECT_DB($GLOBALS['install_mysql']['dbase'], __FILE__, __LINE__) === true) {
						// Check for dumps
						if ((!isFileReadable(postRequestElement('spath') . 'install/tables.sql')) || (!isFileReadable(postRequestElement('spath') . 'install/menu-'.getLanguage().'.sql'))) {
							// Installation area not found
							reportBug(__FILE__, __LINE__, 'SQL dumps not found. Please extract ALL files from the archive or checkout all files out from SVN.');
							return;
						} // END - if

						// Any errors detected?
						if (!ifFatalErrorsDetected()) {
							// Set type, prefix from POST data and database name for later queries
							setConfigEntry('_TABLE_TYPE'  , postRequestElement('mysql', 'type'));
							setConfigEntry('_MYSQL_PREFIX', postRequestElement('mysql', 'prefix'));
							setConfigEntry('__DB_NAME'    , $GLOBALS['install_mysql']['dbase']);

							// Both exists so import them
							foreach (array('tables', 'menu-'.getLanguage()) as $dump) {
								// Should be save here because file_exists() is there but we check it again. :)
								$FQFN = postRequestElement('spath') . 'install/' . $dump . '.sql';

								// Is the file readable?
								if (isFileReadable($FQFN)) {
									// Read the file
									$fileContent = readSqlDump($FQFN);

									// Split it up against ";\n" and merge it into existing SQLs
									mergeSqls(explode(";\n", $fileContent), 'install');
								} else {
									// Not readable!
									reportBug(__FILE__, __LINE__, sprintf("SQL dump %s is not readable.", $dump));
								}
							} // END - foreach
							//* DEBUG: */ die(__FUNCTION__.'['.__LINE__.']:'<pre>'.print_r(getSqls(), true).'</pre>');

							// Are some SQLs found?
							if (countSqls() == 0) {
								// Abort here
								addFatalMessage(__FILE__, __LINE__, '{--INSTALLER_SQL_IMPORT_FAILED--}');
								return;
							} // END - if

							// Now run all queries through
							runFilterChain('run_sqls');

							// Copy the config template and verify it
							doInstallWriteLocalConfigurationFile(postRequestElement('spath'));
						} // END - if
					} // END - if
				} // END - if

				// Are some fatal errors there?
				if (ifFatalErrorsDetected()) {
					$OUT = '';
					foreach (getFatalArray() as $value) {
						$OUT .= '    <li>' . $value . '</li>';
					} // END foreach
					$content['fatal_errors'] = $OUT;
					$OUT = '';
					foreach ($GLOBALS['install_mysql'] as $key => $value) {
						$OUT .= '    <input type="hidden" name="mysql[' . $key . ']" value="' . $value . '" />';
					} // END foreach
					$content['mysql_hidden'] = $OUT;
					$content['spath']      = postRequestElement('spath');
					$content['burl']       = postRequestElement('burl');
					$content['title']      = postRequestElement('title');
					$content['smtp_host']  = postRequestElement('smtp_host');
					$content['smtp_user']  = postRequestElement('smtp_user');
					$content['smtp_pass']  = postRequestElement('smtp_pass1');

					// Load template
					addTemplateToInstallContent('install_fatal_errors', $content);

					// We have handled all fatal errors here
					initFatalMessages();
				} else {
					// Register ext-sql_patches
					if ((registerExtension('sql_patches', NULL)) && (registerExtension('task', NULL))) {
						// Installation is done!
						redirectToUrl('install.php?install_page=finished');
					} else {
						// Something goes wrong on registration of ext-sql_patches
						addFatalMessage(__FILE__, __LINE__, '{--INSTALLER_FINALIZER_CANNOT_REGISTER_SQL_PATCHES--}');
					}
				}
			} else {
				// Something goes wrong during installation! :-(
				addFatalMessage(__FILE__, __LINE__, '{--INSTALLER_FINALIZER_FAILED--}');
			}
			break;

		case 'finished':
			if (isInstalled()) {
				// Load template that we are finished
				addTemplateToInstallContent('install_finished');
			} else {
				// Not finished
				redirectToUrl('install.php');
			}
			break;

		default:
			logDebugMessage(__FILE__, __LINE__, sprintf("Wrong install_page=%s detected", getRequestElement('install_page')));
			addTemplateToInstallContent('admin_settings_unsaved', '{--WRONG_PAGE--}');
			break;
	} // END - switch
} else {
	// Already installed!
	addFatalMessage(__FILE__, __LINE__, '{--ALREADY_INSTALLED--}');
}

// [EOF]
?>
